@@ -1,5 +1,5 @@
 ## File Name: tam.mml.R
-## File Version: 9.8005
+## File Version: 9.802
 
 tam.mml <- function( resp, Y=NULL, group=NULL,  irtmodel="1PL",
             formulaY=NULL, dataY=NULL,
@@ -398,6 +398,7 @@ tam.mml <- function( resp, Y=NULL, group=NULL,  irtmodel="1PL",
     se.xsi.min -> se.xsi
     se.B.min -> se.B
 
+
     #*** include NAs in AXsi
     AXsi <- tam_mml_include_NA_AXsi(AXsi=AXsi, maxcat=maxcat)
 
@@ -510,7 +511,7 @@ tam.mml <- function( resp, Y=NULL, group=NULL,  irtmodel="1PL",
                  "groups"=if ( is.null(group)){1} else { groups },
                  "formulaY"=formulaY, "dataY"=dataY,
                  "pweights"=pweights0,
-                 "time"=c(s1,s2,s2-s1), "A"=A, "B"=B,
+                 "time"=c(s1,s2), "A"=A, "B"=B,
                  "se.B"=se.B,
                  "nitems"=nitems, "maxK"=maxK, "AXsi"=AXsi,
                  "AXsi_"=- AXsi,
